<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Spatium14
 */
global $spatium14_opt; //for redux-options
?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">
	<?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>
	<?php 
	if ( function_exists( 'wp_body_open' ) ) {
		wp_body_open();
	} else {
		do_action( 'wp_body_open' );
	}
	?>
	<div id="page" class="site">
		<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'spatium14' ); ?></a>
		<header id="masthead" class="site-header">
			<?php get_template_part('inc/nav/navbar' ) ; ?>
			<div class="uk-section site-branding  uk-padding-remove-vertical">
				<div class="uk-container">
					<div class="uk-child-width-1-3@m uk-grid-small uk-flex uk-flex-middle" uk-grid>
						<div>
							<div class="uk-card">
								<?php if (is_front_page()) { ?>
									<p class="site-title "> 
										<?php bloginfo( 'name' ) ?>
									</p>
								<?php } else { ?>		 
									<p class="site-title">
										<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?>  </a></p>
									<?php } ?>
								</div>
							</div>
							<div>
								<div class="uk-card">
									<?php
									$spatium14_description = get_bloginfo( 'description', 'display' );
									if ( $spatium14_description || is_customize_preview() ) :
										?>
										<p class="site-description"><?php echo $spatium14_description; /* WPCS: xss ok. */ ?></p>
									<?php endif; ?>
								</div>
							</div>
							<div>
								<div class="uk-card">
									<ul class="head-contact">
										<li>		<!-- phone  -->
											<?php if ($spatium14_opt['phone'] !=''): //field fill check redux phone ?>
												<span uk-icon="icon: phone"></span>	
												<a href="tel://<?php echo esc_attr($spatium14_opt['phone'] = preg_replace('/[^0-9]/', '+', $spatium14_opt['phone']) );  ?>">
													<?php echo esc_html($spatium14_opt['phone']);  ?>
												<?php endif ?>
											</a><!-- phone  -->
										</li>
										<li> <!-- mail  -->
											<!-- other sanitation options break the link  -->
											<?php if(isset($spatium14_opt['mail']) && $spatium14_opt['mail']): ?>
												<span uk-icon="icon: mail"></span>
												<a href="<?php echo esc_url( 'mailto:' .sanitize_email( $spatium14_opt['mail'] ) ); ?>">
													<?php echo esc_attr(sanitize_email($spatium14_opt['mail']) ); ?>
												<?php endif; ?>
											</a>
										</li>
										<li><hr></li>
										<li>
											<?php if ($spatium14_opt['soc-fb'] !=''): //field fill check redux   ?>
												<a 	class="uk-icon-button "  uk-icon="facebook"
												href="<?php echo esc_url($spatium14_opt['soc-fb']);  ?>"> 
											<?php endif ?>	
										</a>
										<?php if ($spatium14_opt['soc-insta'] !=''): //field fill check redux   ?>
											<a class="uk-icon-button" uk-icon="instagram"
											href="<?php echo esc_url($spatium14_opt['soc-insta']);   ?>">
										<?php endif ?>	
									</a>
									<?php if ($spatium14_opt['soc-twit'] !=''): //field fill check redux   ?>
										<a class="uk-icon-button" uk-icon="twitter"
										href="<?php echo esc_url($spatium14_opt['soc-twit']);  ?>">
									<?php endif ?>	
								</a>
							</li>
						</ul>
					</div>
				</div>
			</div>
		</div>
	</div>
</header><!-- #masthead -->
<?php if ((is_front_page())   ) { ?>
	<div class="front-line"></div>
	<div class="uk-section uk-padding-remove">
		<div class="uk-container-expand front-widget">
			<div class="uk-grid-match uk-grid-small" uk-grid>
				<div class="uk-width-3-5@m uk-width-2-3@l">
					<?php if ( is_active_sidebar('h-b-sidebar-1') ) : ?>
						<?php dynamic_sidebar('h-b-sidebar-1' ); ?> 
					<?php endif; ?>
				</div>
				<div class="uk-width-1-5@m uk-width-1-3@l">
					<?php if ( is_active_sidebar('h-s-sidebar-2') ) : ?>
						<?php dynamic_sidebar('h-s-sidebar-2' ); ?> 
					<?php endif; ?>
				</div>
			</div>
		</div>
	</div>
<?php } ?>
<div id="content" class="site-content">
	<div class="line-post"></div>
	<div class="uk-section uk-section-muted uk-padding section-header">
		<div class="uk-container">
			<header class="entry-header uk-text-center">
				<div class="uk-card ">
					<h1 class="entry-title" >  
						<?php if ( is_page() ) {
							echo esc_html( get_the_title() );
						}
						elseif (is_single()) {
							echo esc_html( get_the_title() );
						}
						elseif (is_category()) {
							echo get_queried_object()->name;
						}
						elseif (is_archive()) {
							echo   the_archive_title();  
						}
						elseif (is_home() && ! is_front_page() ) {
							echo single_post_title();
						}
						elseif ( is_post_type_archive() ) {
							post_type_archive_title(); 
						}
						?>
					</h1> <!-- .entry-header -->
				</div>
				<div class="uk-card">
					<?php if (is_front_page()) { ?> 
						<!-- remove the breadcrumb from the home -->
					<?php } else { ?>
						<!-- print to the rest -->
						<?php if ( function_exists('yoast_breadcrumb') )
						{ yoast_breadcrumb('  <div id="breadcrumbs">','</div>'); }
						?>
					<?php } ?>
				</div>
			</header><!-- .entry-header -->	
		</div>
	</div>	
	<div class="line-post"></div>